# standardiser

This is a tool designed to provide a simple way of standardising molecules
as a prelude to e.g. molecular modelling exercises.

To install, download this project and ensure that Python can find
the standardise/ directory.
Note that RDKit must also be installed and accessible to Python.

Or, install via pip:
```
pip install standardiser
```

Please see the IPython Notebooks in docs/ or the HTML versions in docs/html/
for more information. The HTML version is also available for browsing at
https://wwwdev.ebi.ac.uk/chembl/extra/francis/standardiser/.

This work was funded by the IMI eTOX project.

This code is released under the Apache 2.0 license.
Copyright [2014] is retained by the EMBL-EBI.
